summaryrefslogtreecommitdiff
path: root/src/core
diff options
context:
space:
mode:
Diffstat (limited to 'src/core')
-rw-r--r--src/core/commands.c5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/core/commands.c b/src/core/commands.c
index 200dc3d0..614358b8 100644
--- a/src/core/commands.c
+++ b/src/core/commands.c
@@ -282,9 +282,8 @@ void command_runsub(const char *cmd, const char *data,
g_return_if_fail(data != NULL);
if (*data == '\0') {
- /* no subcommand given - unknown command? */
- signal_emit("error command", 2,
- GINT_TO_POINTER(CMDERR_UNKNOWN), cmd);
+ /* no subcommand given - list the subcommands */
+ signal_emit("list subcommands", 2, cmd);
return;
}